L10nSheet class

Constructors

L10nSheet(Sheet sheet, List<List<String?>> data)
从飞书等平台获取的原始表格数据解析为结构化词条列表。
factory
L10nSheet.empty()
L10nSheet.raw(List<String> languages, List<L10nItem> items)

Properties

hashCode int
The hash code for this object.
no setterinherited
itemMap Map<String, L10nItem>
按 key 索引的 Map,懒加载(仅在首次访问时构建)
latefinal
items List<L10nItem>
final
languages List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(L10nSheet other) L10nSheet
合并两个 L10nSheet,相同 key 后者覆盖前者
operator ==(Object other) bool
The equality operator.
inherited