PluralForm enum

ICU 复数/序数形式

Inheritance
Available extensions

Values

zero → const PluralForm
one → const PluralForm
two → const PluralForm
few → const PluralForm
many → const PluralForm
other → const PluralForm

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String s) PluralForm?
从字符串解析,如 "one" → PluralForm.one,未知形式返回 null

Constants

values → const List<PluralForm>
A constant List of the values in this enum, in order of their declaration.