SimpleItem class final

普通文本词条(无占位符)

Excel 示例:greeting | 问候语 | Hello | 你好

Inheritance

Constructors

SimpleItem({required String key, String? description, required Map<String, String> translations})
const

Properties

description → String?
词条描述,来自 Excel description 列(注解行为 null)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translations → Map<String, String>
language → 纯文本
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueFor(String language) → String?
获取指定语言的值,若该语言无翻译则 fallback 到首个非空语言
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited