BaseExporter class abstract

导出器基类

Implementers

Constructors

BaseExporter({required String outputDirPath})
const

Properties

extensionName String?
no setter
fileName String
no setter
fullFileName String
no setter
fullPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
outputDirPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

export(L10nSheet sheetData) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited