Exporter class abstract

单文件导出器

One exporter for one file

Inheritance
Implementers

Constructors

Exporter({required String outputDirPath})
const

Properties

extensionName String?
no setterinherited
fileName String
no setterinherited
fullFileName String
no setterinherited
fullPath String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
outputDirPath String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildFile(File outputFile, L10nSheet sheetData) Future<void>
export(L10nSheet sheetData) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited