PlatformFactory class

平台工厂类

负责根据配置创建对应的平台实例

Constructors

PlatformFactory(Settings settings, {Dio? dio})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Settings
final

Methods

create() Platform
创建平台实例
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited