Settings class
应用配置类
通过依赖注入使用,而不是静态访问
Constructors
- Settings.fromFile([String path = 'excel2l10n.yaml'])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputDirPath → String
-
输出目录路径
no setter
- platformNode → dynamic
-
获取平台配置节点
no setter
- raw → YamlMap
-
获取原始配置 Map
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetNode → dynamic
-
获取目标配置节点
no setter
Methods
-
getValue<
T> (String key) → T? - 安全获取配置值
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited