Localizations class

Inheritance

Constructors

Localizations({required L10nSheet sheetData, required String outputDirPath, required String outputFileName, required String className, required bool genExtension})

Properties

exporters → List<Exporter>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
outputDirPath → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetData → L10nSheet
finalinherited

Methods

export() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited