TargetFactory class

目标工厂类

负责根据配置创建对应的导出目标实例

Constructors

TargetFactory(Settings settings)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Settings
final

Methods

create(L10nSheet sheetData) Target
创建目标实例
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited