PlaceholderItem class final
含类型化占位符词条 {name} / {count:int}
Excel 示例:welcome | | Hello, {name} | 你好,{name} 类型注解示例:fileSize | | {size:double} MB | {size:double} MB
Constructors
-
PlaceholderItem({required String key, String? description, required List<
PlaceholderParam> params, required Map<String, String> translations}) -
const
Properties
- description → String?
-
词条描述,来自 Excel description 列(注解行为 null)
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
finalinherited
-
params
→ List<
PlaceholderParam> -
有序参数列表,顺序以首个非空语言值的出现顺序为准
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translations
→ Map<
String, String> -
language → 含 {name} / {name:type} 的原始模板字符串
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
valueFor(
String language) → String? -
获取指定语言的值,若该语言无翻译则 fallback 到首个非空语言
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited