LocalizationsConfig class

Localizations 配置

用于在各个 Exporter 之间共享配置

Constructors

LocalizationsConfig({required String outputFileName, required String className, required bool genExtension, required String outputDirPath})
const

Properties

className String
final
genExtension bool
final
hashCode int
The hash code for this object.
no setterinherited
outputDirPath String
final
outputFileName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClassName({String? language}) String
getMixinName({String? language}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited