Target class abstract
导出目标接口
定义将本地化数据导出为特定格式的标准接口
- Implementers
Properties
-
exporters
→ List<
BaseExporter> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputDirPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sheetData → L10nSheet
-
final
Methods
-
export(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited